@@ -711,7 +711,22 @@ static void pkg_formatted_field(FILE * fp, pkg_t * pkg, const char *field, const
                 }
                 fprintf(fp, "\n");
             }
-        } else {
+        }
+        else if (strcasecmp(field, "Pre-Depends") == 0) {
+            if (pkg->pre_depends_count) {
+                fprintf(fp, "Pre-Depends:");
+                for (j = 0, i = 0; i < depends_count; i++) {
+                    if (pkg->depends[i].type != PREDEPEND)
+                        continue;
+                    str = pkg_depend_str(pkg, i);
+                    fprintf(fp, "%s %s", j == 0 ? "" : ",", str);
+                    free(str);
+                    j++;
+                }
+                fprintf(fp, "\n");
+            }
+        }
+        else {
             goto UNKNOWN_FMT_FIELD;
         }
         break;
@@ -858,6 +873,7 @@ void pkg_formatted_info(FILE * fp, pkg_t * pkg, const char *fields_filter)
     pkg_formatted_field(fp, pkg, "Package", NULL);
     pkg_formatted_field(fp, pkg, "Version", fields_filter);
     pkg_formatted_field(fp, pkg, "Depends", fields_filter);
+    pkg_formatted_field(fp, pkg, "Pre-Depends", fields_filter);
     pkg_formatted_field(fp, pkg, "Recommends", fields_filter);
     pkg_formatted_field(fp, pkg, "Suggests", fields_filter);
     pkg_formatted_field(fp, pkg, "Provides", fields_filter);
@@ -889,9 +905,14 @@ void pkg_print_status(pkg_t * pkg, FILE * file)
         return;
     }
 
+    int is_installed = (pkg->state_status == SS_INSTALLED
+            || pkg->state_status == SS_UNPACKED
+            || pkg->state_status == SS_HALF_INSTALLED);
+
     pkg_formatted_field(file, pkg, "Package", NULL);
     pkg_formatted_field(file, pkg, "Version", NULL);
     pkg_formatted_field(file, pkg, "Depends", NULL);
+    pkg_formatted_field(file, pkg, "Pre-Depends", NULL);
     pkg_formatted_field(file, pkg, "Recommends", NULL);
     pkg_formatted_field(file, pkg, "Suggests", NULL);
     pkg_formatted_field(file, pkg, "Provides", NULL);
@@ -914,9 +935,11 @@ void pkg_print_status(pkg_t * pkg, FILE * file)
         pkg_formatted_field(file, pkg, "Source", NULL);
         pkg_formatted_field(file, pkg, "Description", NULL);
     }
-    pkg_formatted_field(file, pkg, "Installed-Size", NULL);
-    pkg_formatted_field(file, pkg, "Installed-Time", NULL);
-    pkg_formatted_field(file, pkg, "Auto-Installed", NULL);
+    if (is_installed) {
+        pkg_formatted_field(file, pkg, "Installed-Size", NULL);
+        pkg_formatted_field(file, pkg, "Installed-Time", NULL);
+        pkg_formatted_field(file, pkg, "Auto-Installed", NULL);
+    }
     if (opkg_config->verbose_status_file) {
         pkg_formatted_userfields(file, pkg, NULL);
     }
@@ -1525,7 +1548,11 @@ int pkg_verify(pkg_t * pkg)
             /* Exit with soft error 1 if the package doesn't exist.
              * This allows the caller to download it without nasty
              * messages in the error log.
+             * Remove any matching signature file if it exists.
              */
+            if (opkg_config->check_pkg_signature) {
+                pkg_remove_signature(pkg);
+            }
             return 1;
         }
         else {
@@ -1585,6 +1612,9 @@ int pkg_verify(pkg_t * pkg)
 	opkg_msg(NOTICE, "Removing corrupt package file %s.\n",
              pkg->local_filename);
 	unlink(pkg->local_filename);
+        if (opkg_config->check_pkg_signature) {
+            pkg_remove_signature(pkg);
+        }
 	return err;
     }
     else
